self.__precacheManifest = [
  {
    "revision": "9420a6d9880957cc53d7",
    "url": "./static/css/main.9fbae2cc.chunk.css"
  },
  {
    "revision": "9420a6d9880957cc53d7",
    "url": "./static/js/main.7b866211.chunk.js"
  },
  {
    "revision": "8c97409f0ee389fe75da",
    "url": "./static/js/runtime~main.d653cc00.js"
  },
  {
    "revision": "f8a633bf7d3d5948329a",
    "url": "./static/css/2.19f2448e.chunk.css"
  },
  {
    "revision": "f8a633bf7d3d5948329a",
    "url": "./static/js/2.5b077821.chunk.js"
  },
  {
    "revision": "74cdedb8050c1198d3c477e62d8bd849",
    "url": "./static/media/logo.74cdedb8.png"
  },
  {
    "revision": "4620ac1ea65cc3ec06e0fc74b5d3ae4c",
    "url": "./index.html"
  }
];